@@ -68,6 +68,7 @@ import Data.Functor.Reverse  as Functor
 import Data.Hashable (Hashable)
 import qualified Data.HashMap.Lazy as HMap
 import qualified Data.HashSet      as HSet
+import qualified Data.List.NonEmpty as NEL
 import Data.Time
 import Data.Time.Clock.TAI
 import qualified Data.IntMap as IMap
@@ -346,6 +347,10 @@ instance Serial a => Serial (Seq.Seq a) where
   serialize = serializeWith serialize
   deserialize = deserializeWith deserialize
 
+instance Serial a => Serial (NEL.NonEmpty a) where
+  serialize = serializeWith serialize
+  deserialize = deserializeWith deserialize
+
 instance (Serial a, Ord a) => Serial (Set.Set a) where
   serialize = serialize . Set.toAscList
   deserialize = Set.fromList `liftM` deserialize
@@ -705,6 +710,10 @@ instance Serial1 Seq.Seq where
   serializeWith pv = serializeWith pv . F.toList
   deserializeWith gv = Seq.fromList `liftM` deserializeWith gv
 
+instance Serial1 NEL.NonEmpty where
+  serializeWith pv = serializeWith pv . F.toList
+  deserializeWith gv = NEL.fromList `liftM` deserializeWith gv
+
 {-
 instance Serial1 Set.Set where
   serializeWith pv = serializeWith pv . Set.toAscList
